import { AdRecord } from "../records/ad.record"
import {pool} from "../utils/db";

const defaultObj = new AdRecord({
    title: 'Test Name',
    description: 'blah',
    url: 'htt[s://www.google.com',
    price: 0,
    lat: 9,
    lon: 9,
});

afterAll(async () => {
    await pool.end();
})

test('Can buildAdReocrd', () => {
    const ad = new AdRecord(defaultObj);

    expect(ad.title).toBe('Test Name');
    expect(ad.description).toBe('blah');
})

test('Validate invalid price', () => {
    expect(() => new AdRecord({
        ...defaultObj,
        price: -3
    })).toThrow('Cena nie moze byc mniejsza niz 0 lub przekraczac 9 999 999 PLN');
})

test('AdRecord.insert returns UUID', async () => {
    const ad = new AdRecord({
        // id: 'testowe-id',
        title: 'test123',
        description: 'insert test',
        price: 10,
        url: 'https://google.com',
        lat: 52,
        lon: 21
    })
    await ad.insert();

    expect(ad.id).toBeDefined();
    expect(typeof ad.id).toBe('string');
})

test('AdRecord.insert inserts data to database', async () => {
    const ad = new AdRecord({
        // id: 'testowe-id',
        title: 'test123',
        description: 'insert test',
        price: 10,
        url: 'https://google.com',
        lat: 52,
        lon: 21
    })
    await ad.insert();

    const foundAd = await AdRecord.getOne(ad.id)

    expect(foundAd).toBeDefined();
    expect(foundAd).not.toBeNull();
    expect(foundAd.id).toBe(ad.id);
})

test('Validate getAll() method', async () => {
    const all = await AdRecord.getAll('Test');
    expect(all).toBeTruthy()
})

// test('Validate getAll() - returns smaller amount of data', async () => {
//     const ads = await AdRecord.getAll('Test');
//     expect(ads[0].price).toBeUndefined()
// })

// @TODO Check all of the validation
