"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.MessageRecord = void 0;
const db_1 = require("../utils/db");
const uuid_1 = require("uuid");
const errors_1 = require("../utils/errors");
const secretKeyGenerator_1 = require("../crypto/secretKeyGenerator");
const crypto_1 = require("../crypto/crypto");
class MessageRecord {
    constructor(obj) {
        if (obj.sender == '' || obj.sender.length > 30)
            throw new errors_1.ValidationError("Field sender cannot be empty or longer than 30 characters");
        if (obj.body == '' || obj.body.length > 500)
            throw new errors_1.ValidationError("Message cannot be empty or longer than 500 characters");
        if (typeof obj.toBeDeletedAfter24h != 'boolean')
            throw new errors_1.ValidationError("Value of delete after read field is incorrect");
        this.id = obj.id;
        this.sender = obj.sender;
        this.body = obj.body;
        this.toBeDeletedAfter24h = obj.toBeDeletedAfter24h;
        this.createdAt = obj.createdAt;
        this.secretKey = obj.secretKey;
    }
    insert() {
        return __awaiter(this, void 0, void 0, function* () {
            if (!this.id)
                this.id = (0, uuid_1.v4)();
            if (!this.secretKey)
                this.secretKey = (0, secretKeyGenerator_1.secretKeyGenerator)();
            let isSucces = false;
            const msg = yield (0, crypto_1.encryptMessage)(this.body);
            this.body = msg.body;
            this.ivCrypto = msg.ivCrypto;
            this.keyCrypto = msg.keyCrypto;
            try {
                const [{ affectedRows }] = yield db_1.pool.execute("INSERT INTO `messages` (`id`,`secretKey`,`sender`,`body`, `ivCrypto`, `keyCrypto`) VALUES(:id, :secretKey, :sender, :body, :ivCrypto, :keyCrypto)", {
                    id: this.id,
                    secretKey: this.secretKey,
                    sender: this.sender,
                    body: this.body,
                    ivCrypto: this.ivCrypto,
                    keyCrypto: this.keyCrypto,
                });
                if (affectedRows) {
                    if (this.toBeDeletedAfter24h)
                        this.deleteAfter24h(this.id);
                    return {
                        isSucces: true,
                        secretKey: this.secretKey,
                        sender: this.sender
                    };
                }
            }
            catch (e) {
                console.error("Insert error: ", e);
                return { isSucces };
            }
        });
    }
    static getOne(getMessage) {
        return __awaiter(this, void 0, void 0, function* () {
            const [data] = yield db_1.pool.execute("SELECT `id`, `sender`,`body`, `ivCrypto`, `keyCrypto`, `createdAt` FROM `messages` WHERE sender = :sender AND secretKey = :secretKey", {
                sender: getMessage.sender,
                secretKey: getMessage.secretKey
            });
            if (data.length === 0)
                return null;
            const msg = data[0];
            const msgBody = yield (0, crypto_1.decryptMessage)({ ivCrypto: msg.ivCrypto, body: msg.body, keyCrypto: msg.keyCrypto });
            this.deleteNow(msg.id);
            return {
                sender: msg.sender,
                body: msgBody,
                secretKey: msg.secretKey,
                createdAt: msg.createdAt.toLocaleString()
            };
        });
    }
    deleteAfter24h(id) {
        return __awaiter(this, void 0, void 0, function* () {
            setTimeout(() => __awaiter(this, void 0, void 0, function* () {
                try {
                    yield db_1.pool.execute("DELETE FROM `messages` WHERE id = :id", {
                        id
                    });
                }
                catch (e) {
                    console.error('deleteAfter24h Error: ', e);
                }
            }), 1000 * 60 * 60 * 24);
        });
    }
    static deleteNow(id) {
        return __awaiter(this, void 0, void 0, function* () {
            try {
                yield db_1.pool.execute("DELETE FROM `messages` WHERE id = :id", {
                    id
                });
            }
            catch (e) {
                console.error('deleteNow Error: ', e);
            }
        });
    }
}
exports.MessageRecord = MessageRecord;
//# sourceMappingURL=message.record.js.map